@@ -50,7 +50,7 @@ sub validate {
 	my ($self) = @_;
 
 	# has_validation_class
-	return $self unless $self->can('validation');
+	return $self unless defined $self->value and $self->can('validation');
 
 	$self->value(
 		$self->validation($self->value)
@@ -63,7 +63,7 @@ sub inflate {
 	my ($self) = @_;
 
 	# has_validation_class
-	return $self unless not $self->inflated and $self->can('inflation');
+	return $self unless defined $self->value and not $self->inflated and $self->can('inflation');
 
 	$self->value(
 		$self->inflation($self->value)
@@ -78,7 +78,7 @@ sub deflate {
 	my ($self) = @_;
 
 	# has_validation_class
-	return $self unless $self->inflated && $self->can('deflation');
+	return $self unless defined $self->value and $self->inflated and $self->can('deflation');
 
 	$self->value(
 		$self->deflation($self->value)
