@@ -7,10 +7,10 @@ extends 'ODS::Table::Column::Base';
 use ODS::Utils qw/error/;
 
 sub validation {
-        if (ref($_[1])) {
-                croak sprintf "The value passed to the %s column does not match the integer constraint.",
-                        $_[0]->name;
-        }
+	if (ref($_[1])) {
+		croak sprintf "The value passed to the %s column does not match the string constraint.",
+			$_[0]->name;
+	}
 	return $_[1];
 }
 
